Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1632)

Unified Diff: chrome/browser/ui/gtk/tabs/dragged_view_gtk.h

Issue 23531053: ui/base/animation -> ui/gfx/animation (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merge 2 trunk Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/gtk/status_bubble_gtk.cc ('k') | chrome/browser/ui/gtk/tabs/dragged_view_gtk.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/gtk/tabs/dragged_view_gtk.h
diff --git a/chrome/browser/ui/gtk/tabs/dragged_view_gtk.h b/chrome/browser/ui/gtk/tabs/dragged_view_gtk.h
index ff931f7c2fbc294e044d89caf37d7832dda86c30..58fdce6c8e2124e66173c188ec77cb9558d61fbf 100644
--- a/chrome/browser/ui/gtk/tabs/dragged_view_gtk.h
+++ b/chrome/browser/ui/gtk/tabs/dragged_view_gtk.h
@@ -11,9 +11,9 @@
#include "base/callback.h"
#include "base/compiler_specific.h"
-#include "ui/base/animation/animation_delegate.h"
-#include "ui/base/animation/slide_animation.h"
#include "ui/base/gtk/gtk_signal.h"
+#include "ui/gfx/animation/animation_delegate.h"
+#include "ui/gfx/animation/slide_animation.h"
#include "ui/gfx/canvas.h"
#include "ui/gfx/point.h"
#include "ui/gfx/rect.h"
@@ -22,7 +22,7 @@
class DragData;
class TabRendererGtk;
-class DraggedViewGtk : public ui::AnimationDelegate {
+class DraggedViewGtk : public gfx::AnimationDelegate {
public:
DraggedViewGtk(DragData* drag_data,
const gfx::Point& mouse_tab_offset,
@@ -93,10 +93,10 @@ class DraggedViewGtk : public ui::AnimationDelegate {
gfx::Point GetDistanceFromTabStripOriginToMousePointer();
private:
- // Overridden from ui::AnimationDelegate:
- virtual void AnimationProgressed(const ui::Animation* animation) OVERRIDE;
- virtual void AnimationEnded(const ui::Animation* animation) OVERRIDE;
- virtual void AnimationCanceled(const ui::Animation* animation) OVERRIDE;
+ // Overridden from gfx::AnimationDelegate:
+ virtual void AnimationProgressed(const gfx::Animation* animation) OVERRIDE;
+ virtual void AnimationEnded(const gfx::Animation* animation) OVERRIDE;
+ virtual void AnimationCanceled(const gfx::Animation* animation) OVERRIDE;
// Arranges the contents of the dragged tab.
void Layout();
@@ -175,7 +175,7 @@ class DraggedViewGtk : public ui::AnimationDelegate {
gfx::Size contents_size_;
// The animation used to slide the attached tab to its final location.
- ui::SlideAnimation close_animation_;
+ gfx::SlideAnimation close_animation_;
// A callback notified when the animation is complete.
base::Closure animation_callback_;
« no previous file with comments | « chrome/browser/ui/gtk/status_bubble_gtk.cc ('k') | chrome/browser/ui/gtk/tabs/dragged_view_gtk.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698